****************
Sage観光ツアー
****************

この節では，Sageを使えばどんなことできるのか，その一端をご覧にいれる．
「…を作るにはどうやるの？」という質問全般に答える "Sage Constructions"ドキュメントには，さらに豊富な実例が用意されている．
加えて "Sage Reference Manual"では，数千の具体例が見つかるはずだ．Sageノートブックの ``Help`` リンクをクリックすれば、このツアーの内容を対話的に確認することもできる．

(このチュートリアルをSageノートブックから閲覧している場合，入力セルの内容を実行するには ``shift-enter`` と押せばよい． ``shift-enter`` を押して実行する前に入力セルの中身を変更することもで きる．Macマシンでは， ``shift-enter`` ではなく ``shift-return`` を押すことになるかもしれない．)

.. toctree::

   tour_assignment
   tour_help
   tour_algebra
   tour_plotting
   tour_functions
   tour_rings
   tour_linalg
   tour_polynomial
   tour_coercion
   tour_groups
   tour_numtheory
   tour_advanced
